@@ -115,6 +115,8 @@ async def smart_dedup(
     system_prompt: str = None,
     prompt_template: str = None,
     entity_embeddings: Optional[list[list[float]]] = None,
+    use_fuzzy_str_matching: bool = True,
+    use_embedding_matching: bool = True,
     verbose: bool = False,
 ):
     """
@@ -134,6 +136,8 @@ async def smart_dedup(
         system_prompt (str, optional): Optional system prompt for the match selection model.
         prompt_template (str, optional): Optional prompt template for the match selection model.
         entity_embeddings (list[list[float]], optional): Precomputed embeddings for entities. If None, embeddings will be computed. Defaults to None.
+        use_fuzzy_str_matching (bool, optional): If True, uses fuzzy string matching to find potential duplicates. Defaults to True.
+        use_embedding_matching (bool, optional): If True, uses embedding-based matching to find potential
         verbose (bool, optional): If True, displays progress bars and additional output. Defaults to False.
         
     Returns:
@@ -149,41 +153,51 @@ async def smart_dedup(
     # AUTOGENERATED! DO NOT EDIT! File to edit: ../../../../../../../../../Users/lukastk/dev/2025-03-25_00__adulib/pts/api/algos/01_smart_dedup.pct.py.
     
     # %% auto 0
-    __all__ = ['entities', 'fuzzy_match_candidates', 'dist_matrix', 'embedding_match_candidates', 'system_prompt', 'prompt_template',
-               'tasks', 'matches', 'entities_without_matches']
+    __all__ = ['entities', 'system_prompt', 'prompt_template', 'tasks', 'matches', 'entities_without_matches']
     
-    # %% ../../../../../../../../../Users/lukastk/dev/2025-03-25_00__adulib/pts/api/algos/01_smart_dedup.pct.py 9
+    # %% ../../../../../../../../../Users/lukastk/dev/2025-03-25_00__adulib/pts/api/algos/01_smart_dedup.pct.py 8
     _entities = set(entities)
     entities = list(_entities)
     
-    fuzzy_match_candidates = [
-        [
-            candidate for candidate, _, _, in
-            fuzzy_match(entity, _entities - {entity}, max_results=max_fuzzy_str_matches, min_similarity=min_fuzzy_str_match_score, scorer=fuzzy_str_match_scorer)
-        ] for entity in entities
-    ]
-    
-    # %% ../../../../../../../../../Users/lukastk/dev/2025-03-25_00__adulib/pts/api/algos/01_smart_dedup.pct.py 11
-    if entity_embeddings is None:
-        embeddings = await async_batch_embeddings(
-            model=embedding_model,
-            input=entities,
-            batch_size=1000,
-            verbose=verbose,
-        )
+    # %% ../../../../../../../../../Users/lukastk/dev/2025-03-25_00__adulib/pts/api/algos/01_smart_dedup.pct.py 10
+    if use_fuzzy_str_matching:
+        fuzzy_match_candidates = [
+            [
+                candidate for candidate, _, _, in
+                fuzzy_match(entity, _entities - {entity}, max_results=max_fuzzy_str_matches, min_similarity=min_fuzzy_str_match_score, scorer=fuzzy_str_match_scorer)
+            ] for entity in entities
+        ]
     else:
-        if len(entity_embeddings) != len(entities):
-            raise ValueError("Length of entity_embeddings must match length of entities.")
-        embeddings = entity_embeddings  
+        fuzzy_match_candidates = [
+            [] for _ in range(len(entities))
+        ]
     
-    dist_matrix = get_vector_dist_matrix(embeddings, metric='cosine')
+    # %% ../../../../../../../../../Users/lukastk/dev/2025-03-25_00__adulib/pts/api/algos/01_smart_dedup.pct.py 12
+    if use_embedding_matching:
+        if entity_embeddings is None:
+            embeddings = await async_batch_embeddings(
+                model=embedding_model,
+                input=entities,
+                batch_size=1000,
+                verbose=verbose,
+            )
+        else:
+            if len(entity_embeddings) != len(entities):
+                raise ValueError("Length of entity_embeddings must match length of entities.")
+            embeddings = entity_embeddings  
     
-    embedding_match_candidates = [
-        [entities[match_i] for match_i in embedding_match(i, dist_matrix, num_matches=num_embedding_matches)[0]]
-        for i in range(len(entities))
-    ]
+        dist_matrix = get_vector_dist_matrix(embeddings, metric='cosine')
     
-    # %% ../../../../../../../../../Users/lukastk/dev/2025-03-25_00__adulib/pts/api/algos/01_smart_dedup.pct.py 15
+        embedding_match_candidates = [
+            [entities[match_i] for match_i in embedding_match(i, dist_matrix, num_matches=num_embedding_matches)[0]]
+            for i in range(len(entities))
+        ]
+    else:
+        embedding_match_candidates = [
+            [] for _ in range(len(entities))
+        ]
+    
+    # %% ../../../../../../../../../Users/lukastk/dev/2025-03-25_00__adulib/pts/api/algos/01_smart_dedup.pct.py 16
     system_prompt = system_prompt or default_system_prompt
     prompt_template = prompt_template or default_prompt_template
     
